@@ -129,6 +129,36 @@ class Newton:
             return res.json()
         else:
             return res.text
+
+    def get_task_deep_link(self,task_id: str=None):
+        api_url = f"{self.api_base}/task/deep_link/{task_id}"
+
+        res = requests.get(api_url, headers=self.__headers)       
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def create_task_deep_link(self,task_id: str=None,user_name: str=None,user_email: str=None,role: str=None,expire_in: int=None,return_url: str=None):
+        api_url = f"{self.api_base}/task/deep_link/{task_id}"
+
+        params = {}
+        if user_name is not None:
+            params["user_name"] = user_name
+        if user_email is not None:
+            params["user_email"] = user_email
+        if role is not None:
+            params["role"] = role
+        if expire_in is not None :    
+            params["expire_in"] = expire_in
+        if return_url is not None:
+            params["return_url"] = return_url
+
+        res = requests.put(api_url, params=params, headers=self.__headers)       
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
  
     def create_project(self, body: dict):
         api_url = f"{self.api_base}/project"
@@ -184,6 +214,38 @@ class Newton:
         else:
             return res.text
 
+    def export_project_tasks(self, project_id: str=None, export_note: str=None):
+        
+        api_url = f"{self.api_base}/task/export/{project_id}"
+
+        params = {}
+        if export_note is not None:
+            params["export_note"] = export_note
+
+        res = requests.get(api_url, params=params, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def list_project_exports(self, project_id: str=None):
+        api_url = f"{self.api_base}/task/export_list/{project_id}"
+
+        res = requests.get(api_url, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def download_project_export(self, export_id: str=None):
+        api_url = f"{self.api_base}/task/export_download/{export_id}"
+
+        res = requests.get(api_url, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
     def create_dataset(self, body: dict):
         api_url = f"{self.api_base}/dataset"
 
@@ -228,6 +290,48 @@ class Newton:
         else:
             return res.text
 
+    def delete_dataset(self, dataset_id):
+        api_url = f"{self.api_base}/dataset/{dataset_id}"
+
+        res = requests.delete(api_url, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def export_dataset(self, dataset_id: str=None, export_note: str=None,project_id: str=None):
+        api_url = f"{self.api_base}/dataset/export/{dataset_id}"
+
+        params = {}
+        if export_note is not None:
+            params["export_note"] = export_note
+        if project_id is not None:
+            params["project_id"] = project_id
+
+        res = requests.get(api_url, params=params, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def list_dataset_exports(self, dataset_id: str=None):
+        api_url = f"{self.api_base}/dataset/export_list/{dataset_id}"
+
+        res = requests.get(api_url, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text
+
+    def download_dataset_export(self, export_id: str=None):
+        api_url = f"{self.api_base}/dataset/export_download/{export_id}"
+
+        res = requests.get(api_url, headers=self.__headers)
+        if res.ok:
+            return res.json()
+        else:
+            return res.text        
+
     def create_dataset_item(self, body: dict):
         api_url = f"{self.api_base}/dataset_item"
 
